package
Version:
v0.0.0-...-517d9f4
Opens a new window with list of versions in this module.
Published: Sep 18, 2022
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package hetergeneous_data_structure
Time : 2021/5/25 7:00 下午
Author : xushiyin
contact : yuqingxushiyin@gmail.com
type Node struct {
NextNode *Node
Property rune
}
Node struct
func CreateLinkedList() *Node
CreateLinkedList create linked list
ReverseLinkedList reverse list
Source Files
¶
Click to show internal directories.
Click to hide internal directories.