Documentation
¶
Overview ¶
Package linear_data_structure Time : 2021/5/10 8:21 下午 Author : xushiyin contact : yuqingxushiyin@gmail.com please check go standard package container/list, this is very important!!!
Package linear_data_structure Time : 2021/5/9 10:23 下午 Author : xushiyin contact : yuqingxushiyin@gmail.com LinkedList is a sequence of nodes that have properties and a reference to the next node in the sequence. It is a linear data structure that is used to store data. The data structure permits the addition and deletion of components from any node next to another node. They are not stored contiguously in memory, which makes them different arrays.
Package linear_data_structure Time : 2021/5/11 9:42 上午 Author : xushiyin contact : yuqingxushiyin@gmail.com
Package linear_data_structure Time : 2021/5/11 9:22 上午 Author : xushiyin contact : yuqingxushiyin@gmail.com
Package linear_data_structure Time : 2021/5/11 7:47 下午 Author : xushiyin contact : yuqingxushiyin@gmail.com
Package linear_data_structure Time : 2021/5/11 9:38 上午 Author : xushiyin contact : yuqingxushiyin@gmail.com
Index ¶
- func PowerSeries(a int) (int, int)
- type DNode
- type DoubleLinkedList
- type Element
- type LinkedList
- func (linkedList *LinkedList) AddAfter(nodeProperty int, property int)
- func (linkedList *LinkedList) AddBefore(nodeProperty int, property int)
- func (linkedList *LinkedList) AddToEnd(p int)
- func (linkedList *LinkedList) AddToHead(p int)
- func (linkedList *LinkedList) DelEnd()
- func (linkedList *LinkedList) DelHead()
- func (linkedList *LinkedList) DelNodeWithValue(p int)
- func (linkedList *LinkedList) DelNodeWithValue1(p int)
- func (linkedList *LinkedList) DelNodeWithValueX(p int)
- func (linkedList *LinkedList) IterateList()
- func (linkedList *LinkedList) LastNode() *Node
- func (linkedList *LinkedList) LinkedListLen() int
- func (linkedList *LinkedList) NodeWithValue(p int) *Node
- type Node
- type Order
- type Queue
- type Set
- type Stack
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func PowerSeries ¶
PowerSeries gets the power series of integer a and returns tuple of square and cube
Types ¶
type DoubleLinkedList ¶
type DoubleLinkedList struct {
HeadNode *DNode
}
DoubleLinkedList class
func (*DoubleLinkedList) AddAfter ¶
func (dLinkedList *DoubleLinkedList) AddAfter(nodeProperty, property int)
AddAfter method of DoubleLinkedList
func (*DoubleLinkedList) AddToHead ¶
func (dLinkedList *DoubleLinkedList) AddToHead(property int)
AddToHead method of DoubleLinkedList
func (*DoubleLinkedList) NodeBetweenValues ¶
func (dLinkedList *DoubleLinkedList) NodeBetweenValues(firstProperty, secondProperty int) *DNode
NodeBetweenValues method of DoubleLinkedList
func (*DoubleLinkedList) NodeWithValue ¶
func (dLinkedList *DoubleLinkedList) NodeWithValue(p int) *DNode
NodeWithValue method returns DNode given parameter Property
type LinkedList ¶
type LinkedList struct {
HeadNode *Node
}
LinkedList class
func (*LinkedList) AddAfter ¶
func (linkedList *LinkedList) AddAfter(nodeProperty int, property int)
AddAfter method adds a node with nodeProperty after node with Property
func (*LinkedList) AddBefore ¶
func (linkedList *LinkedList) AddBefore(nodeProperty int, property int)
AddBefore method adds a node with nodeProperty before node with Property
func (*LinkedList) AddToEnd ¶
func (linkedList *LinkedList) AddToEnd(p int)
AddToEnd method adds the node with Property to the end
func (*LinkedList) AddToHead ¶
func (linkedList *LinkedList) AddToHead(p int)
AddToHead method of LinkedList class
func (*LinkedList) DelEnd ¶
func (linkedList *LinkedList) DelEnd()
DelEnd method delete the last node
func (*LinkedList) DelHead ¶
func (linkedList *LinkedList) DelHead()
DelHead method of LinkedList class
func (*LinkedList) DelNodeWithValue ¶
func (linkedList *LinkedList) DelNodeWithValue(p int)
DelNodeWithValue method delete node with value
func (*LinkedList) DelNodeWithValue1 ¶
func (linkedList *LinkedList) DelNodeWithValue1(p int)
DelNodeWithValue1 method delete node with value 教科书
func (*LinkedList) DelNodeWithValueX ¶
func (linkedList *LinkedList) DelNodeWithValueX(p int)
DelNodeWithValueX method delete node Linux
func (*LinkedList) IterateList ¶
func (linkedList *LinkedList) IterateList()
IterateList method iterates over LinkedList
func (*LinkedList) LastNode ¶
func (linkedList *LinkedList) LastNode() *Node
LastNode method returns the last Node
func (*LinkedList) LinkedListLen ¶
func (linkedList *LinkedList) LinkedListLen() int
LinkedListLen method delete node with vale
func (*LinkedList) NodeWithValue ¶
func (linkedList *LinkedList) NodeWithValue(p int) *Node
NodeWithValue method returns Node given parameter Property
type Set ¶
type Set struct {
// contains filtered or unexported fields
}
Set class
func (*Set) AddElement ¶
AddElement adds the element to the set
func (*Set) ContainsElement ¶
ContainsElement judge the element whether in set
func (*Set) DeleteElement ¶
DeleteElement deletes the element from the set